import fedmsg
import fedmsg.encoding

from . import config
from . import JobTrigger

ITEM_TYPE = 'compose'


class ComposeCompletedJobTrigger(JobTrigger):
    topic = "org.fedoraproject.prod.compose.*"
    jsonify = False
    config_key = 'taskotron.composecompletedjobtrigger.enabled'

    def __init__(self, *args, **kw):
        super(ComposeCompletedJobTrigger, self).__init__(*args, **kw)

    def consume(self, message):
        usable_message = fedmsg.encoding.loads(message.body)

        topic = usable_message['topic']

        if not 'branched.complete' in topic and not 'rawhide.complete' in topic:
            return

        branch = usable_message['msg']['branch']
        arch = usable_message['msg']['arch']

        # non empty arch means secondary arch
        if arch:
            return

        self.log.debug('should be scheduling job for completed compose: %s' % branch)

        self.trigger_tasks(branch, ITEM_TYPE, config.compose_completed_tasks, ['noarch'])
